SystemOrganization addCategory: #'Pier-Deploy-Core'!

Object subclass: #PRDeployUtility
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Deploy-Core'!

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 17:06'!
addAuthenticationFilter: application

	application configuration addParent: WAAuthConfiguration instance.
	application
		preferenceAt: #login put: 'admin';
		preferenceAt: #passwordHash put: (GRPlatform current secureHashFor: 'pier');
		yourself.
	^ application addFilter: WAAuthenticationFilter new
! !

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 20:57'!
adminEntryPoints
	^ #(
'/config'
'/status'
'/tools/classbrowser'
'/tools/screenshot'
'/tools/versionuploader'
'/tools/vnc'
	)! !

!PRDeployUtility class methodsFor: 'build-customize' stamp: 'YanniChiu 8/13/2010 23:58'!
changePasswordsTo: password
	"Change various passwords to differ from the build script values.
	Example:
		self changePasswordsTo: 'abcde'
	"

	self adminEntryPoints
		do: [ :each | 
			| application |
			application := WADispatcher default handlerAt: each.
			"application configuration addParent: WAAuthConfiguration instance."
			application
				preferenceAt: #login put: 'admin';
				preferenceAt: #passwordHash put: (GRPlatform current secureHashFor: password);
				yourself
			"application addFilter: WAAuthenticationFilter new." ].
	(PRKernel instanceNamed: 'pier') adminUser password: password.
	"((PRKernel instanceNamed: 'pier') userNamed: 'demo' ifNone: [  ]) password: password."
	(RFBServer current)
		setFullPassword: password;
		setViewPassword: password;
		yourself! !

!PRDeployUtility class methodsFor: 'build-customize' stamp: 'YanniChiu 6/6/2011 21:07'!
changeServerHostname: serverHostname port: port
	"Set the serverHostname of all deployed entry points.
	Example use:
		self changeServerHostname: 'demo.com' port: 80
		self changeServerHostname: 'localhost' port: 8080
	"

	self adminEntryPoints , self publicEntryPoints
		do: [ :each | 
			| application |
			application := WADispatcher default handlerAt: each.
			application
				preferenceAt: #serverProtocol put: 'http';
				preferenceAt: #serverPort put: port;
				preferenceAt: #serverHostname put: serverHostname;
				"preferenceAt: #serverPath put: '/';"
				yourself
			 ]! !

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 23:43'!
prepareImage
	"self prepareImage"

	Author fullName: 'deployed'.
	self prepareVncServer.
	self prepareSeaside.
! !

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 21:49'!
prepareSeaside

	"Turn off the Seaside toolbar"
	WAAdmin applicationDefaults removeParent: WADevelopmentConfiguration instance.

	WADispatcher default withDescendantsDo: [:each |
		each isApplication
			ifTrue: [ | pathString |
				pathString := each hierarchyPathString.
				"Set access control on all Seaside admin tools"
				(self adminEntryPoints includes: pathString)
					ifTrue: [ self addAuthenticationFilter: each ]
					ifFalse: [
						"Trim all but the public entry points"
						(self publicEntryPoints includes: pathString)
							ifFalse: [ WAAdmin unregister: pathString ]
					]
			]
	].

	"Unregister empty dispatchers"
	WADispatcher default withDescendantsDo: [:each |
		(each isDispatcher and: [ each handlers isEmpty ])
			ifTrue: [ WAAdmin unregister: each hierarchyPathString ]
	]
! !

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 16:57'!
prepareVncServer
	"Set up RFB/VNC Server for production deployment"
	(RFBServer current)
		initializePreferences;
		configureForMemoryConservation;
		allowEmptyPasswords: false;
		setFullPassword: 'pier';
		setViewPassword: 'pier';
		"start: 1;" "Use WAVNCController to start/stop"
		yourself.
! !

!PRDeployUtility class methodsFor: 'build-image-setup' stamp: 'YanniChiu 11/4/2010 20:57'!
publicEntryPoints
	^ #('/browse' '/files' '/pier')! !

!PRDeployUtility class methodsFor: 'registering' stamp: 'YanniChiu 6/6/2011 21:05'!
register
	"PRKernel reset.
	PRKernel instances add: self kernel."
	WAKom withAllSubclasses do: [:each | each stop].
	WAKom startOn: self portno! !
